@@ -43,6 +43,7 @@ class _Namespaces:
     CAPS: str = 'http://jabber.org/protocol/caps'
     CAPTCHA: str = 'urn:xmpp:captcha'
     CARBONS: str = 'urn:xmpp:carbons:2'
+    CHANNEL_BINDING: str = 'urn:xmpp:sasl-cb:0'
     CHATMARKERS: str = 'urn:xmpp:chat-markers:0'
     CHATSTATES: str = 'http://jabber.org/protocol/chatstates'
     CLIENT: str = 'jabber:client'
@@ -62,6 +63,7 @@ class _Namespaces:
     DOMAIN_BASED_NAME: str = 'urn:xmpp:domain-based-name:1'
     EME: str = 'urn:xmpp:eme:0'
     ENCRYPTED: str = 'jabber:x:encrypted'
+    FALLBACK: str = 'urn:xmpp:fallback:0'
     FASTEN: str = 'urn:xmpp:fasten:0'
     FILE_METADATA: str = 'urn:xmpp:file:metadata:0'
     FORWARD: str = 'urn:xmpp:forward:0'
@@ -138,6 +140,7 @@ class _Namespaces:
     RECEIPTS: str = 'urn:xmpp:receipts'
     REGISTER: str = 'jabber:iq:register'
     REGISTER_FEATURE: str = 'http://jabber.org/features/iq-register'
+    REPLY: str = 'urn:xmpp:reply:0'
     REPORTING: str = 'urn:xmpp:reporting:0'
     ROSTER: str = 'jabber:iq:roster'
     ROSTERNOTES: str = 'storage:rosternotes'
@@ -145,7 +148,7 @@ class _Namespaces:
     ROSTER_VER: str = 'urn:xmpp:features:rosterver'
     RSM: str = 'http://jabber.org/protocol/rsm'
     SASL: str = 'urn:ietf:params:xml:ns:xmpp-sasl'
-    SASL2: str = 'urn:xmpp:sasl:1'
+    SASL2: str = 'urn:xmpp:sasl:2'
     SEARCH: str = 'jabber:iq:search'
     SECLABEL: str = 'urn:xmpp:sec-label:0'
     SECLABEL_CATALOG: str = 'urn:xmpp:sec-label:catalog:2'
